==> kie-wb-common-dmn-client-7.39.0.Final-redhat-00007-test-sources.jar: org/kie/workbench/common/dmn/client/editors/types/imported/treelist/TreeListSubItemViewTest.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.dmn.client.editors.types.imported.treelist;

import elemental2.dom.HTMLElement;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.runners.MockitoJUnitRunner;

import static org.junit.Assert.assertEquals;

@RunWith(MockitoJUnitRunner.class)
public class TreeListSubItemViewTest {

    @Mock
    private HTMLElement description;

    @Mock
    private HTMLElement details;

    private TreeListSubItemView view;

    @Before
    public void setup() {
        view = new TreeListSubItemView(description, details);
    }

    @Test
    public void testSetDescription() {

        final String text = "Description";
        view.setDescription(text);

        assertEquals(text, description.textContent);
    }

    @Test
    public void setDetails() {

        final String text = "Details";
        view.setDetails(text);

        assertEquals(text, details.textContent);
    }
}

==> kie-wb-common-dmn-client-7.52.0.Final-redhat-00007-test-sources.jar: org/kie/workbench/common/dmn/client/editors/types/imported/treelist/TreeListSubItemViewTest.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.dmn.client.editors.types.imported.treelist;

import elemental2.dom.HTMLElement;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;

import static org.junit.Assert.assertEquals;

@RunWith(MockitoJUnitRunner.class)
public class TreeListSubItemViewTest {

    @Mock
    private HTMLElement description;

    @Mock
    private HTMLElement details;

    private TreeListSubItemView view;

    @Before
    public void setup() {
        view = new TreeListSubItemView(description, details);
    }

    @Test
    public void testSetDescription() {

        final String text = "Description";
        view.setDescription(text);

        assertEquals(text, description.textContent);
    }

    @Test
    public void setDetails() {

        final String text = "Details";
        view.setDetails(text);

        assertEquals(text, details.textContent);
    }
}
